@@ -379,11 +379,11 @@ class SenderQQ(QThread):
 
     def send(self, param):
         self.logger.debug("sending")
-        param["source"]=APP_KEY
         
         param["clientip"]="127.0.0.1"
-        param["jing"]=param["long"]
-        param["wei"]=param["lat"]
+        #param["jing"]=param["long"]
+        #param["wei"]=param["lat"]
+        param["syncflag"]="1"
         
         if param["timelineType"]==4:
             param["content"]=param["comment"]
