@@ -134,6 +134,7 @@ class MaoboApp(QApplication):
         self.commentid_seed = 0
     
         self.create_accounts_window()
+        self.defaultWin = None
         if len(self.accounts)==0:
             self.create_default_window()
             self.defaultWin.show()
@@ -168,6 +169,7 @@ class MaoboApp(QApplication):
             self.connect(self, SIGNAL("lastWindowClosed()"), self.lastWindowClosed)
             
         self.doReloadBackgroundIcon()
+        self.show_notice("﻿提示：Maebo 应用由 漫魔应用(http://Www.MaemoApp.Com) 提供技术支持及维护，近期新浪微博接口升级，可能会导致您无法正常使用，届时请前往漫魔中国论坛向我们反馈，并获取最新版本信息。", 0)
           
     def lastWindowClosed(self):
         print "lastWindowClosed"
