@@ -117,7 +117,19 @@ class Comments(Model):
 
     def favorite(self):
         return self._api.create_favorite(self.id)
+        
+class Userlist(Model):
 
+    @classmethod
+    def parse(cls, api, json):
+        userlist = cls(api)
+        for k, v in json.items():
+            if k == 'users':
+                users = User.parse_list(api, v)
+                setattr(userlist, k, users)                
+            else:
+                setattr(userlist, k, v)
+        return userlist
 class User(Model):
 
     @classmethod
@@ -333,7 +345,7 @@ class Counts(Model):
     @classmethod
     def parse(cls, api, json):
         ids = Counts(api)
-        for k, v in json.items():            
+        for k, v in json.items():  
             setattr(ids, k, v)
         return ids
     
@@ -346,6 +358,7 @@ class ModelFactory(object):
 
     status = Status
     comments = Comments
+    userlist = Userlist
     user = User
     direct_message = DirectMessage
     friendship = Friendship
